Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
netrun / rbac / __init__.py |  | 8 | 0 | 0 |  | 100%
netrun / rbac / dependencies.py |  | 58 | 14 | 0 |  | 76%
netrun / rbac / exceptions.py |  | 24 | 5 | 0 |  | 79%
netrun / rbac / models.py |  | 58 | 0 | 0 |  | 100%
netrun / rbac / policies.py |  | 63 | 8 | 0 |  | 87%
netrun / rbac / tenant.py |  | 36 | 21 | 1 |  | 42%
netrun / rbac / testing.py |  | 294 | 222 | 0 |  | 24%
netrun / rbac / tests / __init__.py |  | 0 | 0 | 0 |  | 100%
netrun / rbac / tests / conftest.py |  | 7 | 7 | 0 |  | 0%
netrun / rbac / tests / test_tenant_isolation.py |  | 319 | 319 | 2 |  | 0%
Total |  | 867 | 596 | 3 |  | 31%

No items found using the specified filter.